<?php

/**
 * Banner Section
 *
 * @package dark_fitness
 */

$wp_customize->add_section(
	'dark_fitness_banner_section',
	array(
		'panel'    => 'dark_fitness_front_page_options',
		'title'    => esc_html__( 'Banner Section', 'dark-fitness' ),
		'priority' => 10,
	)
);

// Banner Section - Enable Section.
$wp_customize->add_setting(
	'dark_fitness_enable_banner_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'dark_fitness_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dark_Fitness_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dark_fitness_enable_banner_section',
		array(
			'label'    => esc_html__( 'Enable Banner Section', 'dark-fitness' ),
			'section'  => 'dark_fitness_banner_section',
			'settings' => 'dark_fitness_enable_banner_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'dark_fitness_enable_banner_section',
		array(
			'selector' => '#dark_fitness_banner_section .section-link',
			'settings' => 'dark_fitness_enable_banner_section',
		)
	);
}

// Banner Section - Banner Slider Content Type.
$wp_customize->add_setting(
	'dark_fitness_banner_slider_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'dark_fitness_sanitize_select',
	)
);

$wp_customize->add_control(
	'dark_fitness_banner_slider_content_type',
	array(
		'label'           => esc_html__( 'Select Banner Slider Content Type', 'dark-fitness' ),
		'section'         => 'dark_fitness_banner_section',
		'settings'        => 'dark_fitness_banner_slider_content_type',
		'type'            => 'select',
		'active_callback' => 'dark_fitness_is_banner_slider_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'dark-fitness' ),
			'post' => esc_html__( 'Post', 'dark-fitness' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Banner Section - Banner Subtitle.
	$wp_customize->add_setting(
		'dark_fitness_banner_subtitle_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'dark_fitness_banner_subtitle_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Subtitle %d', 'dark-fitness' ), $i ),
			'section'         => 'dark_fitness_banner_section',
			'settings'        => 'dark_fitness_banner_subtitle_' . $i,
			'type'            => 'text',
			'active_callback' => 'dark_fitness_is_banner_slider_section_enabled',
		)
	);

	// Banner Section - Select Banner Post.
	$wp_customize->add_setting(
		'dark_fitness_banner_slider_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'dark_fitness_banner_slider_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'dark-fitness' ), $i ),
			'section'         => 'dark_fitness_banner_section',
			'settings'        => 'dark_fitness_banner_slider_content_post_' . $i,
			'active_callback' => 'dark_fitness_is_banner_slider_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => dark_fitness_get_post_choices(),
		)
	);

	// Banner Section - Select Banner Page.
	$wp_customize->add_setting(
		'dark_fitness_banner_slider_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'dark_fitness_banner_slider_content_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Page %d', 'dark-fitness' ), $i ),
			'section'         => 'dark_fitness_banner_section',
			'settings'        => 'dark_fitness_banner_slider_content_page_' . $i,
			'active_callback' => 'dark_fitness_is_banner_slider_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => dark_fitness_get_page_choices(),
		)
	);

	// Banner Section - Button Label.
	$wp_customize->add_setting(
		'dark_fitness_banner_button_label_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'dark_fitness_banner_button_label_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Button Label %d', 'dark-fitness' ), $i ),
			'section'         => 'dark_fitness_banner_section',
			'settings'        => 'dark_fitness_banner_button_label_' . $i,
			'type'            => 'text',
			'active_callback' => 'dark_fitness_is_banner_slider_section_enabled',
		)
	);

	// Banner Section - Button Link.
	$wp_customize->add_setting(
		'dark_fitness_banner_button_link_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'dark_fitness_banner_button_link_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Button Link %d', 'dark-fitness' ), $i ),
			'section'         => 'dark_fitness_banner_section',
			'settings'        => 'dark_fitness_banner_button_link_' . $i,
			'type'            => 'url',
			'active_callback' => 'dark_fitness_is_banner_slider_section_enabled',
		)
	);
}
